"""
PixTrail - A simple tool to generate GPX tracks from geotagged photos.

This package extracts GPS data from image EXIF metadata and
creates GPX files that can be used in mapping applications.
"""

__version__ = "1.3.0"
